==> pybleno-0.8.tar.gz: pybleno-0.8/pybleno/BlenoPrimaryService.py <==
from . import UuidUtil
import json
from .hci_socket import Emit

class BlenoPrimaryService(dict):
    def __init__(self, options):
        self['uuid'] = UuidUtil.removeDashes(options['uuid'])
        self['characteristics'] = options['characteristics'] if 'characteristics' in options else []
        
    def __str__(self):
        return json.dumps({
            uuid: self['uuid'],
            characteristics: self['characteristics']
        })

    def __setitem__(self, key, item):
        self.__dict__[key] = item

    def __getitem__(self, key):
        return self.__dict__[key]

    def __repr__(self):
        return repr(self.__dict__)

    def __len__(self):
        return len(self.__dict__)

    def __delitem__(self, key):
        del self.__dict__[key]

    def clear(self):
        return self.__dict__.clear()

    def copy(self):
        return self.__dict__.copy()

    def has_key(self, k):
        return k in self.__dict__

    def update(self, *args, **kwargs):
        return self.__dict__.update(*args, **kwargs)

    def keys(self):
        return self.__dict__.keys()

    def values(self):
        return self.__dict__.values()

    def items(self):
        return self.__dict__.items()

    def pop(self, *args):
        return self.__dict__.pop(*args)

    def __cmp__(self, dict_):
        return self.__cmp__(self.__dict__, dict_)

    def __contains__(self, item):
        return item in self.__dict__

    def __iter__(self):
        return iter(self.__dict__)

    def __unicode__(self):
        return unicode(repr(self.__dict__))        
        
        
Emit.Patch(BlenoPrimaryService)

==> pybleno-0.11.tar.gz: pybleno-0.11/pybleno/BlenoPrimaryService.py <==
from . import UuidUtil
import json
from .hci_socket import Emit


class BlenoPrimaryService(dict):
    def __init__(self, options):
        super().__init__()
        self['uuid'] = UuidUtil.removeDashes(options['uuid'])
        self['characteristics'] = options['characteristics'] if 'characteristics' in options else []

    def __str__(self):
        return json.dumps({
            'uuid':            self['uuid'],
            'characteristics': self['characteristics']
        })

    def __setitem__(self, key, item):
        self.__dict__[key] = item

    def __getitem__(self, key):
        return self.__dict__[key]

    def __repr__(self):
        return repr(self.__dict__)

    def __len__(self):
        return len(self.__dict__)

    def __delitem__(self, key):
        del self.__dict__[key]

    def clear(self):
        return self.__dict__.clear()

    def copy(self):
        return self.__dict__.copy()

    def has_key(self, k):
        return k in self.__dict__

    def update(self, *args, **kwargs):
        return self.__dict__.update(*args, **kwargs)

    def keys(self):
        return self.__dict__.keys()

    def values(self):
        return self.__dict__.values()

    def items(self):
        return self.__dict__.items()

    def pop(self, *args):
        return self.__dict__.pop(*args)

    def __cmp__(self, dict_):
        return self.__cmp__(self.__dict__, dict_)

    def __contains__(self, item):
        return item in self.__dict__

    def __iter__(self):
        return iter(self.__dict__)

    def __unicode__(self):
        return unicode(repr(self.__dict__))


Emit.Patch(BlenoPrimaryService)
